/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#ifndef UTILSVIDEO_CONVERTER_H
#define UTILSVIDEO_CONVERTER_H

#include <QString>
#include <QObject>
#include <QProcess>
#include <string>

using namespace std;



namespace utils {


   /**
    * @class Video_Converter
    * @brief Clase que se encarga de ejecutar el proceso de conversion.
    *
    * Esta clase se encarga de llevar a cabo el proceso de covnersion, utilizando
    * el MEncoder. Utiliza la clase QProcess para levantar el proceso del
    * MEncoder. Se encuenta dentro del namespace utils.
    * Hereda de la clase QObject para tener acceso al sistema de signals y slots.
    *
    * Su funcionamiento es el siguiente:
    * Se construye recibiendo como entrada el directorio destino para los archivos
    * convertidos. Se llama a la funcion convert pasandoles los datos necesarios
    * para la conversion de un video. Se ejecuta el proceso del MEncoder y se
    * comienza a convertir.
    * En el constructor se define que cada vez que haya informacion disponible
    * en la salida estandar, se procese esa informacion y se emitan las signals
    * Percent_Completed y Time_Remaining, las cuales pueden ser conectadas en la
    * app principal con slots especificos para saber el porciento completado y
    * el tiempo restante.
    * Cuando termina de convertir el video, emite la signal Process_Has_Finished,
    * para informar que ha concluido el proceso de conversion.
    */
   class Video_Converter : public QObject
   {
      Q_OBJECT

        public:
      Video_Converter( QString, QObject *parent = 0 );
      Video_Converter( QObject *parent = 0 );
      ~Video_Converter();

      void convert( QString output_name,
                    QString command, QString rmencoder);
      void set_Output_Dir( QString );
      string get_OutPut_Dir();
      string get_Output_File();
      string get_OutPut_Name();
      void Cancel_Process();

        private:
      QString m_output_directory;
      QString m_command;
      QString m_output_name;
      QProcess *mencoder_process;

        signals:
      void Percent_Completed( const int & );
      void Time_Remaining( const QString & );
      void Process_Has_Finished();

        private slots:
      void Read_Output_Info();
      void Finished_Process();

        public slots:
      void Stop_Process();
   };

}

#endif
