/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#include <QApplication>
#include "main_window.h"
#include "req_manager.h"
#include "lenguage.h"
#include <iostream>
using namespace std;

// used for the one-instance property
#include <QProcess>
#include <QDir>
#include <stdio.h>


#ifdef Q_OS_LINUX
QString bmencoder = "/usr/bin/mencoder";
QString bmplayer = "/usr/bin/mplayer";
QString dir_fuentes = "./Fonts";
#endif
// "/usr/share/qeven/fonts/"

#ifdef Q_OS_WIN32
QString bmencoder = "MPlayer\\mencoder.exe";
QString bmplayer = "MPlayer\\mplayer.exe";
QString dir_fuentes = "./";
#endif

int main( int argc, char *argv[] )
{
   QApplication app(argc, argv);
   Q_INIT_RESOURCE(application);
   lenguage lengua;
   QTranslator translator;
   if(lengua.activeLang != -1)
   {
      translator.load(lengua.langFileName[lengua.activeLang] );
      qApp->installTranslator(&translator);
   }

   //one-instance pre-check
   QProcess* p = new QProcess;
   QString file =  QDir::homePath().append( "/.processList.qpl" );
   // get the path in the correct OS-like way
   file = QDir::toNativeSeparators( file );

   p->setStandardOutputFile( file );

   // set the correct command
#ifdef Q_OS_WIN32
   QString command = "tasklist";
#endif
#ifdef Q_OS_LINUX
   QString command = "ps -A -o comm=";
#endif

   // execute command
   p->start( command );
   p->execute( command );
   p->closeWriteChannel();
   p->close();

   // read the processList and search for qeven instance
   char buffer[1024];
   FILE *f1 = fopen ( file.toStdString().c_str(), "r" );
   if( NULL == f1 )
   {
      QMessageBox::critical( 0, "Error", QObject::tr( "No se puede leer el fichero de comprobacion inicial" ) );
      exit( 101 );
   }
   else
   {
      bool found = false;

      while ( !feof( f1 ) )
      {
         fgets ( buffer, sizeof( buffer ), f1 );
         QString line( buffer );
         line = line.toLower();

         if( line.contains( "qeven" ) )
         {
            if( found == true )
            {
               QMessageBox::critical( 0, "Error", QObject::tr( "QEVEN ya se esta ejecutando, solo se permite 1 instancia" ) );
               exit( 1 );
            }
            else    // if found == false ... set to true
            {
               found = true;
            }
         }

         line = "";
      }

      fclose(f1);
   }
   // end of one-instance pre-check


   req_manager* sp = new req_manager( bmencoder, bmplayer );

   Main_Window* mw = new Main_Window;
   if(argc == 1)
   {
      QObject::connect( sp, SIGNAL( splash_finished() ),
                        mw, SLOT( Show_Wizard() ) );
   }
   else
   {
      if(argc == 2)
         mw->Load(app.arguments().at(1));

      QObject::connect( sp, SIGNAL( splash_finished() ),
                        mw, SLOT( show() ) );


   }

   if( !sp->show( app ) )
   {
      return 1;
   }

   mw->SetProgramDir(sp->bmencoder,sp->bmplayer);
   sp->finish( *mw );
   //mw->show();

   int exitCode = app.exec();

   return exitCode;
}
